@@ -43,6 +43,7 @@ typedef struct
 	u_int d_port, s_port;
 	int state;
 	int is_policy;
+	char interface[16];
 }
 rule_t;
 
@@ -65,7 +66,9 @@ typedef enum
 	CMD_CLEAR,
 	CMD_LOAD,
 	CMD_SAVE,
-	CMD_CHANGE
+	CMD_CHANGE,
+	CMD_CFG_LOAD,
+	CMD_CFG_DONTLOAD
 }
 pkcommand_t;
 
@@ -104,6 +107,7 @@ typedef struct
 pkmessage_t;
 
 #define PK_SOCKET "/tmp/.gpe_shield_icm"
+#define LOADRULES_MARK "/etc/gpe/gpe-shield-load"
 
 extern int suidloop (int sock);
 extern void do_rules_apply();
